<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>åpne</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Feil ved utskrivning av valgte fil.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message>
        <source>Sail corners coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>clew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Definisjon av seilet</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Seil dimensjoner</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Posisjonen til avrundingen</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Forlikets lengde</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Lengde underkant</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Akterlikets lengde</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel lengde</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Akterlikets avrunding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel avrunding</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Forlikets avrunding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Underlikets avrunding</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grad</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Gaffel vinkel/forlik</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Riggens Mål</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Foten J av framre trekant</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Høyde på skjøtefeste</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Avstand fra nedhal til skjøtefeste</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Storseil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fokke</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Høyde I av framre trekant</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Lengde på båten</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Mastelogg</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Stoff</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Søm bredde</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Stoff bredde</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Mitre kutt</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Kryss kutt</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Vridd underlik</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Horisontalt kutt</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Antall baner</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Antall radial paneler</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Radial kutt</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Vertikal kutt</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Seilets form</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Dybde i toppen</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Dybde på midten</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Dybde ved underliket</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Bretten på akterliket</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Andre brett kanter</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Skjøtevinkel</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Seilets areal</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Beregn</translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation>Seil ID</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Antall baner i forlik</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Vinkel</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Seil ID</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD Håndbok</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>seil &amp;TXT</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>seil &amp;XML</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;åpne</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensjoner</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Mal</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Lapper</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Rigg</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Bilde</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation>Informasjon om Sailcut</translation>
    </message>
    <message>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Feil ved utskrivning av valgte fil.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informasjon om Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation>Informasjon om Sailcut</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Åpne &amp;siste</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>&amp;Eksporter 3D seil</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>til &amp;Carlson plotter</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Eksporter &amp;utvikling</translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation>Sailcut &amp;Håndbok</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>visning i 3D</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>visning av omriss</translation>
    </message>
    <message>
        <source>development</source>
        <translation>utskytningsoversikt</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>laget nytt seil</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>lastet inn &apos;%1&apos;</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>feil ved lasting av &apos;%1&apos;</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>skrev &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Feil ved utskrift av data</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Feil ved utskrift av paneler</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Feil ved utskrift av tegning</translation>
    </message>
    <message>
        <source>data</source>
        <translation>data</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>tegning</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">lag paneler</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Skriv ut</translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation>Kuttliste</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Seiltype</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Storseil</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Fokke</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Seil layout</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Kryss kutt</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Horisontalt kutt</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Radial kutt</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Vridd underlik kutt</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Vertikalt kutt</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Mitre kutt</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation>baner</translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete">Antall paneler i topp.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation>Rigg</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Båtens LOA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Høyde I av framre trekant</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Foten J av framre trekant</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Nedhalets posisjon X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Nedhalets høyde Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Seil dimensjoner</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Forlikets lengde</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffelens vinkel på forliket</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Gaffel lengde</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Lengde underkant</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Akterlikets lengde</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Form på seilets lik</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Forlikets avrunding</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Gaffel avrunding</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Akterlikets avrunding</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Underlikets avrunding</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Plassering av forlikets avrunding</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Plassering av gaffelens avrunding</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Plassering av akterlikets avrunding</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Plassering av underlikets avrunding</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Innstillinger for seil</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Skjøtevinkel</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Stoff søm og bretter</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Stoff bredde</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Søm bredde</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Bredde på akterlikets søm</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Bredde på andre sømmer</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Seil mal</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Forlikets faktor</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Akterlikets faktor</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Topp profil</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Midtre profil  h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Nedre profil</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Mastelogg</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation> Antall paneler i topp,   </translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation>baner i forlik.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grad</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Vertikal oppdeling</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Seil mal</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Topp profil</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Mitre profil</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Nedre profil</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Rigg</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>seil &amp;definisjoner</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>3D &amp;seil</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>&amp;Legg til seil</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;åpne</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Åpne &amp;siste</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Feil ved utskrivning av valgte fil</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Seilinformasjon</translation>
    </message>
    <message>
        <source>file</source>
        <translation>fil</translation>
    </message>
    <message>
        <source>name</source>
        <translation>navn</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Forny</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Oppdater</translation>
    </message>
    <message>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Feil ved lesning av valgte fil.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">OpenGL er ikke tilgjengelig.</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Vis parametrene</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>elevasjon</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimuth</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Forny bildet</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Etiketter</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom ut</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>grader</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Luff shape</source>
        <translation>Forlikets form</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Akterlikets form</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Feil ved lesning av valgte fil.</translation>
    </message>
</context>
</TS>
